@@ -74,7 +74,7 @@ class DuplicateParameterException(ParameterException):
 
 class Parameter(object):
     """
-    An untyped Parameter
+    Parameter whose value is a ``str``, and a base class for other parameter types.
 
     Parameters are objects set on the Task class level to make it possible to parameterize tasks.
     For instance:
@@ -108,9 +108,6 @@ class Parameter(object):
 
         * Any default value set using the ``default`` flag.
 
-    There are subclasses of ``Parameter`` that define what type the parameter has. This is not
-    enforced within Python, but are used for command line interaction.
-
     Parameter objects may be reused, but you must then set the ``positional=False`` flag.
     """
     _counter = 0  # non-atomically increasing counter used for ordering parameters.
@@ -255,10 +252,14 @@ class Parameter(object):
 
         :param x: the value to serialize.
         """
-        if not isinstance(x, six.string_types) and self.__class__ == Parameter:
-            warnings.warn("Parameter {0} is not of type string.".format(str(x)))
         return str(x)
 
+    def _warn_on_wrong_param_type(self, param_name, param_value):
+        if self.__class__ != Parameter:
+            return
+        if not isinstance(param_value, six.string_types):
+            warnings.warn('Parameter "{}" with value "{}" is not of type string.'.format(param_name, param_value))
+
     def normalize(self, x):
         """
         Given a parsed parameter value, normalizes it.
@@ -695,8 +696,6 @@ class TimeDeltaParameter(Parameter):
 
         :param x: the value to serialize.
         """
-        if not isinstance(x, datetime.timedelta) and self.__class__ == TimeDeltaParameter:
-            warnings.warn("Parameter {0} is not of type timedelta.".format(str(x)))
         weeks = x.days // 7
         days = x.days % 7
         hours = x.seconds // 3600
@@ -705,6 +704,12 @@ class TimeDeltaParameter(Parameter):
         result = "{} w {} d {} h {} m {} s".format(weeks, days, hours, minutes, seconds)
         return result
 
+    def _warn_on_wrong_param_type(self, param_name, param_value):
+        if self.__class__ != TimeDeltaParameter:
+            return
+        if not isinstance(param_value, datetime.timedelta):
+            warnings.warn('Parameter "{}" with value "{}" is not of type timedelta.'.format(param_name, param_value))
+
 
 class TaskParameter(Parameter):
     """
@@ -777,7 +782,7 @@ class EnumParameter(Parameter):
         return e.name
 
 
-class FrozenOrderedDict(Mapping):
+class _FrozenOrderedDict(Mapping):
     """
     It is an immutable wrapper around ordered dictionaries that implements the complete :py:class:`collections.Mapping`
     interface. It can be used as a drop-in replacement for dictionaries where immutability and ordering are desired.
@@ -810,6 +815,17 @@ class FrozenOrderedDict(Mapping):
         return self.__dict
 
 
+def _recursively_freeze(value):
+    """
+    Recursively walks ``Mapping``s and ``list``s and converts them to ``_FrozenOrderedDict`` and ``tuples``, respectively.
+    """
+    if isinstance(value, Mapping):
+        return _FrozenOrderedDict(((k, _recursively_freeze(v)) for k, v in value.items()))
+    elif isinstance(value, list):
+        return tuple(_recursively_freeze(v) for v in value)
+    return value
+
+
 class DictParameter(Parameter):
     """
     Parameter whose value is a ``dict``.
@@ -843,20 +859,20 @@ class DictParameter(Parameter):
     values (like a database connection config).
     """
 
-    class DictParamEncoder(JSONEncoder):
+    class _DictParamEncoder(JSONEncoder):
         """
-        JSON encoder for :py:class:`~DictParameter`, which makes :py:class:`~FrozenOrderedDict` JSON serializable.
+        JSON encoder for :py:class:`~DictParameter`, which makes :py:class:`~_FrozenOrderedDict` JSON serializable.
         """
         def default(self, obj):
-            if isinstance(obj, FrozenOrderedDict):
+            if isinstance(obj, _FrozenOrderedDict):
                 return obj.get_wrapped()
             return json.JSONEncoder.default(self, obj)
 
     def normalize(self, value):
         """
-        Ensure that dictionary parameter is converted to a FrozenOrderedDict so it can be hashed.
+        Ensure that dictionary parameter is converted to a _FrozenOrderedDict so it can be hashed.
         """
-        return FrozenOrderedDict(value)
+        return _recursively_freeze(value)
 
     def parse(self, s):
         """
@@ -869,10 +885,10 @@ class DictParameter(Parameter):
 
         :param s: String to be parse
         """
-        return json.loads(s, object_pairs_hook=FrozenOrderedDict)
+        return json.loads(s, object_pairs_hook=_FrozenOrderedDict)
 
     def serialize(self, x):
-        return json.dumps(x, cls=DictParameter.DictParamEncoder)
+        return json.dumps(x, cls=DictParameter._DictParamEncoder)
 
 
 class ListParameter(Parameter):
@@ -912,7 +928,7 @@ class ListParameter(Parameter):
         :param str x: the value to parse.
         :return: the normalized (hashable/immutable) value.
         """
-        return tuple(x)
+        return _recursively_freeze(x)
 
     def parse(self, x):
         """
